pub struct CloudWatch {}Expand description
A factory for creating various AWS CloudWatch logging implementations.
This factory provides entry points for three primary CloudWatch logging strategies:
- Config-based: Explicitly providing AWS credentials and region.
- Env-based: Automatic credential discovery using the standard AWS environment variables.
- Cout-based: JSON-formatted stdout logging for Lambda, ECS, and Fargate.
Implementations
Sourceimpl CloudWatch
impl CloudWatch
Sourcepub fn config(self, config: CloudWatchConfig) -> CloudWatchConfig
pub fn config(self, config: CloudWatchConfig) -> CloudWatchConfig
Begins building a CloudWatch logger using a manual configuration.
Sourcepub fn env<S>(self, log_group: S) -> CloudWatchEnv
pub fn env<S>(self, log_group: S) -> CloudWatchEnv
Begins building a CloudWatch logger that pulls credentials from the environment.
Sourceimpl CloudWatch
impl CloudWatch
Sourcepub fn cout(self) -> CloudWatchCout
pub fn cout(self) -> CloudWatchCout
Begins building a CloudWatch stdout JSON logger.
This is recommended for AWS Lambda and containerized services where the log driver handles the actual AWS API interaction.